Learn R Programming

PopPsiSeqR (version 1.0.0)

PopPsiSeqR-package: PopPsiSeqR: Process and Visualize Evolve & Resequence Experiments

Description

Handle data from evolve and resequence experiments. Measured allele frequencies (e.g., from variants called from high-throughput sequencing data) are compared using an update of the PsiSeq algorithm (Earley, Eric and Corbin Jones (2011) tools:::Rd_expr_doi("10.1534/genetics.111.129445")). Functions for saving and loading important files are also included, as well as functions for basic data visualization.

Arguments

Author

Maintainer: Charles Soeder csoeder@email.unc.edu [copyright holder]

See Also