This function accepts as input a path to a file in an extended BED6+ format; specifically,
`chrom start end name score strand reference_allele alternate_allele selected_parent_count selected_parent_allele_frequency backcrossed_parent_count backcrossed_parent_allele_frequency offspring_count offspring_allele_frequency`
eg,
`chr2L 8517 8518 0 0 + G A 8 0 16 0.25 8 0.25`
Some of these fields (name, score, strand, reference_allele, alternate_allele, selected_parent_count, backcrossed_parent_count, offspring_count) are required as placeholders but not used in the current PopPsiSeq algorithm
This format is the output of joining and filtering the output of vcftools' --freq output; see vignette for details